@@ -1,15 +1,8 @@
 import asyncio
-from contextlib import suppress
 import logging
+from contextlib import suppress
 
-from async_dns.core import (
-    RandId,
-    DNSMessage,
-    types,
-    REQUEST,
-    Record,
-)
-
+from async_dns.core import REQUEST, DNSMessage, RandId, Record, types
 from pyroute2 import IPRoute
 
 from .network import SystemNetworkData
@@ -57,6 +50,7 @@ class PTRResolver:
         self.responses = {}
         self.send_qid = None
         self.responded = asyncio.Event()
+        self.error = None
 
     def connection_lost(self, transport):
         """Connection lost."""
@@ -74,12 +68,19 @@ class PTRResolver:
         if msg.qid == self.send_qid:
             self.responded.set()
 
+    def error_received(self, exc):
+        """Error received."""
+        self.error = exc
+        self.responded.set()
+
     async def send_query(self, query):
         """Send a query and wait for a response."""
         self.responded.clear()
         self.send_qid = query.qid
         self.transport.sendto(query.pack(), self.destination)
         await self.responded.wait()
+        if self.error:
+            raise self.error
 
 
 async def async_query_for_ptrs(nameserver, ips_to_lookup):
@@ -91,21 +92,27 @@ async def async_query_for_ptrs(nameserver, ips_to_lookup):
         lambda: PTRResolver(destination), remote_addr=destination
     )
     try:
-        return await _async_query_for_ptrs(protocol, ips_to_lookup)
+        return await async_query_for_ptr_with_proto(protocol, ips_to_lookup)
     finally:
         transport.close()
 
 
-async def _async_query_for_ptrs(protocol, ips_to_lookup):
+def async_generate_ptr_query(rand_id, ip):
+    """Generate a ptr query with the next random id."""
+    req = DNSMessage(qr=REQUEST)
+    req.qd = [Record(REQUEST, ip_to_ptr(str(ip)), types.PTR)]
+    req.qid = rand_id.get()
+    rand_id.put(req.qid)
+    return req
+
+
+async def async_query_for_ptr_with_proto(protocol, ips_to_lookup):
     """Send and receiver the PTR queries."""
     time_outs = 0
     query_for_ip = {}
     rand_id = RandId()
     for ip in ips_to_lookup:
-        req = DNSMessage(qr=REQUEST)
-        req.qd = [Record(REQUEST, ip_to_ptr(str(ip)), types.PTR)]
-        req.qid = rand_id.get()
-        rand_id.put(req.qid)
+        req = async_generate_ptr_query(rand_id, ip)
         query_for_ip[ip] = req.qid
         try:
             await asyncio.wait_for(
@@ -115,6 +122,8 @@ async def _async_query_for_ptrs(protocol, ips_to_lookup):
             time_outs += 1
             if time_outs == MAX_DNS_TIMEOUT_DECLARE_DEAD_NAMESERVER:
                 break
+        except OSError:
+            break
 
     return [protocol.responses.get(query_for_ip.get(ip)) for ip in ips_to_lookup]
 
@@ -161,7 +170,7 @@ class DiscoverHosts:
         ips = []
         for host in sys_network_data.network.hosts():
             if len(ips) > MAX_ADDRESSES:
-                _LOGGER.warning(
+                _LOGGER.debug(
                     "Max addresses of %s reached for network: %s",
                     MAX_ADDRESSES,
                     sys_network_data.network,
